@@ -31,7 +31,7 @@ def lookupCat(orth):
     return cat
 
 def filterNGrams(ngram_path):
-    qs = Orthography.objects.filter(word_form__frequency__gt=10)#.prefetch_related()
+    qs = Orthography.objects.filter(wordform__frequency__gt=10)#.prefetch_related()
     #qs = qs.exclude(spelling__contains="'")
     #qs = qs.exclude(spelling__contains=".")
     #qs = qs.exclude(spelling__contains=",")
